# S4D Sequence Mixer

::: linax.sequence_mixers.s4d.S4DSequenceMixerConfig
    options:
      members:
        - build

---

::: linax.sequence_mixers.s4d.S4DSequenceMixer
    options:
      members:
        - __init__
        - __call__
